Flot |version|
==============


.. include:: ../README.rst

Documentation contents
----------------------

.. toctree::
   :maxdepth: 2

   rationale
   pyproject_toml
   cmdline
   reproducible

.. toctree::
   :maxdepth: 1

   development
   history

Indices and tables
==================

* :ref:`genindex`
* :ref:`search`

